Class: GMT

Inherits:
Object
  • Object
show all
Defined in:
lib/gmt.rb

Overview

This class provides a native extension accessing the programs of the Generic Mapping Tools; an open source collection of about 80 command-line tools for manipulating geographic and Cartesian data sets (including filtering, trend fitting, gridding, projecting, etc.) and producing PostScript illustrations ranging from simple x–y plots via contour maps to artificially illuminated surfaces and 3D perspective views

An example of usage:

require 'gmt'

common = {
  file: 'output.ps',
  R: '0/3/0/2',
  J: 'x1i'
}
gmt = GMT.new
gmt.psxy('dots.xy',
         common.merge(
           position: :first,
           S: 'c0.50c',
           G: 'blue'))
gmt.psxy('dots.xy',
         common.merge(
           position: :last,
           S: 'c0.25c',
           G: 'red'))

Those familiar with GMT will recognise the -R (range) and -J (projection) options which are now keys for the program options hash.

The session

All GMT functions (modules in the GMT parlance) require a session context, and an instance of the GMT class is exactly such a context.

gmt = GMT.new

There are no arguments for the constructor.

GMT functions

Each GMT function is available as instance method, and each has the same signatures: several arguments, typically input files, followed by a single options hash. The options has corresponds to the command-line options of the GMT program; hence the shell command

gmt makecpt -Cgebco depths.txt -i2 -Z -E24 > my_depths.cpt

would be replicated by the Ruby

gmt = GMT.new
gmt.makecpt('depths.txt',
            :C => 'gebco', :i => 2, :Z => nil, :E => 24, :> => 'my_depths.cpt')

Note that

  • the single argument (the input file 'depths.txt') preceeds the options hash

  • the options hash has keys which are symbols

  • options which lack arguments correspond to hash keys with nil values :Z => nil.

  • the output redirection is also treated as hash option, with key :> and value which is the output file.

PostScript functions

When creating complex PostScript plots one needs to make several calls to GMT functions, to use the -O and -K options, and to append output of the second and subsequent calls (rather than overwriting). This is tiresome and error-prone on the command-line, and more so in the “options hash” representation in the Ruby module.

So we add some syntatactic sugar for these PostScript functions: if the options hash has the keys :position (with values one of :first, :middle, or :last) and :file (with the value of the ouptut file), then the -O and -K options and the output redirection are handled by the class. So one might write

gmt = GMT.new
gmt.psbasemap( , :file => 'map.ps', :position => :first)
gmt.pstext(    , :file => 'map.ps', :position => :middle)
gmt.psxy(      , :file => 'map.ps', :position => :middle)
gmt.(    , :file => 'map.ps', :position => :last)

Filtering of 1-D and 2-D Data collapse

Plotting of 1-D and 2-D Data collapse

Gridding of Data Tables collapse

Sampling of 1-D and 2-D Data collapse

Projection and Map-transformation collapse

Retrieve Information collapse

Mathematical Operations on Tables or Grids collapse

Convert or Extract Subsets of Data collapse

Determine Trends in 1-D and 2-D Data collapse

Other Operations on 2-D Grids collapse

Miscellaneous Tools collapse

Instance Method Summary collapse

Constructor Details

#initializeObject



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'ext/gmt/gmt.c', line 49

static VALUE gmt_init(VALUE self)
{
  gmt_t *gmt;

  Data_Get_Struct(self, gmt_t, gmt);

  gmt->session =
    GMT_Create_Session("Session name", 2, 0, NULL);

  if (gmt->session == NULL)
    rb_raise(rb_eNoMemError, "failed to create GMT session");

  return self;
}

Instance Method Details

#blockmean(*arguments, options) ⇒ Boolean

L2 (x,y,z) table data filter/decimator

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



198
# File 'lib/gmt.rb', line 198

wrapper_other :blockmean

#blockmedian(*arguments, options) ⇒ Boolean

L1 (x,y,z) table data filter/decimator

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



201
# File 'lib/gmt.rb', line 201

wrapper_other :blockmedian

#blockmode(*arguments, options) ⇒ Boolean

Mode estimate (x,y,z) table data filter/decimator

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



204
# File 'lib/gmt.rb', line 204

wrapper_other :blockmode

#filter1d(*arguments, options) ⇒ Boolean

Time domain filtering of 1-D data tables

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



207
# File 'lib/gmt.rb', line 207

wrapper_other :filter1d

#fitcircle(*arguments, options) ⇒ Boolean

Finds the best-fitting great or small circle for a set of points

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



402
# File 'lib/gmt.rb', line 402

wrapper_other :fitcircle

#freeObject



64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'ext/gmt/gmt.c', line 64

static VALUE gmt_release(VALUE self)
{
  gmt_t *gmt;

  Data_Get_Struct(self, gmt_t, gmt);

  if (gmt->session)
    {
      GMT_Destroy_Session(gmt->session);
      gmt->session = NULL;
    }

  return self;
}

#gmt2kml(*arguments, options) ⇒ Boolean

Like psxy but plots KML for use in Google Earth

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



450
# File 'lib/gmt.rb', line 450

wrapper_other :gmt2kml

#gmtconnect(*arguments, options) ⇒ Boolean

Connect segments into more complete lines or polygons

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



360
# File 'lib/gmt.rb', line 360

wrapper_other :gmtconnect

#gmtconvert(*arguments, options) ⇒ Boolean

Convert data tables from one format to another

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



363
# File 'lib/gmt.rb', line 363

wrapper_other :gmtconvert

#gmtdefaults(*arguments, options) ⇒ Boolean

List the current default settings

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



321
# File 'lib/gmt.rb', line 321

wrapper_other :gmtdefaults

#gmtget(*arguments, options) ⇒ Boolean

Retrieve selected parameters in current file

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



324
# File 'lib/gmt.rb', line 324

wrapper_other :gmtget

#gmtinfo(*arguments, options) ⇒ Boolean

Get information about table data files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



327
# File 'lib/gmt.rb', line 327

wrapper_other :gmtinfo

#gmtlogo(*files, options) ⇒ Boolean

Plot the GMT logo on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



216
# File 'lib/gmt.rb', line 216

wrapper_ps :gmtlogo

#gmtmath(*arguments, options) ⇒ Boolean

Mathematical operations on table data

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



339
# File 'lib/gmt.rb', line 339

wrapper_other :gmtmath

#gmtregress(*arguments, options) ⇒ Boolean

Linear regression of 1-D data sets

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



405
# File 'lib/gmt.rb', line 405

wrapper_other :gmtregress

#gmtselect(*arguments, options) ⇒ Boolean

Select subsets of table data based on multiple spatial criteria

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



366
# File 'lib/gmt.rb', line 366

wrapper_other :gmtselect

#gmtset(*arguments, options) ⇒ Boolean

Change selected parameters in current file

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



330
# File 'lib/gmt.rb', line 330

wrapper_other :gmtset

#gmtsimplify(*arguments, options) ⇒ Boolean

Line reduction using the Douglas-Peucker algorithm

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



294
# File 'lib/gmt.rb', line 294

wrapper_other :gmtsimplify

#gmtspatial(*arguments, options) ⇒ Boolean

Geospatial operations on lines and polygons

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



369
# File 'lib/gmt.rb', line 369

wrapper_other :gmtspatial

#gmtvector(*arguments, options) ⇒ Boolean

Operations on Cartesian vectors in 2-D and 3-D

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



372
# File 'lib/gmt.rb', line 372

wrapper_other :gmtvector

#grd2cpt(*arguments, options) ⇒ Boolean

Make color palette table from a grid files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



417
# File 'lib/gmt.rb', line 417

wrapper_other :grd2cpt

#grd2rgb(*arguments, options) ⇒ Boolean

Convert Sun raster or grid file to red, green, blue component grids

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



375
# File 'lib/gmt.rb', line 375

wrapper_other :grd2rgb

#grd2xyz(*arguments, options) ⇒ Boolean

Conversion from 2-D grid file to table data

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



378
# File 'lib/gmt.rb', line 378

wrapper_other :grd2xyz

#grdblend(*arguments, options) ⇒ Boolean

Blend several partially over-lapping grid files onto one grid

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



381
# File 'lib/gmt.rb', line 381

wrapper_other :grdblend

#grdclip(*arguments, options) ⇒ Boolean

Limit the z-range in gridded data sets

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



420
# File 'lib/gmt.rb', line 420

wrapper_other :grdclip

#grdcontour(*files, options) ⇒ Boolean

Contouring of 2-D gridded data sets

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



219
# File 'lib/gmt.rb', line 219

wrapper_ps :grdcontour

#grdconvert(*arguments, options) ⇒ Boolean

Converts grid files into other grid formats

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



384
# File 'lib/gmt.rb', line 384

wrapper_other :grdconvert

#grdcut(*arguments, options) ⇒ Boolean

Cut a sub-region from a grid file

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



387
# File 'lib/gmt.rb', line 387

wrapper_other :grdcut

#grdedit(*arguments, options) ⇒ Boolean

Modify header information in a 2-D grid file

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



423
# File 'lib/gmt.rb', line 423

wrapper_other :grdedit

#grdfft(*arguments, options) ⇒ Boolean

Perform operations on grid files in the frequency domain

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



426
# File 'lib/gmt.rb', line 426

wrapper_other :grdfft

#grdfilter(*arguments, options) ⇒ Boolean

Filter 2-D gridded data sets in the space domain

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



210
# File 'lib/gmt.rb', line 210

wrapper_other :grdfilter

#grdgradient(*arguments, options) ⇒ Boolean

Compute directional gradient from grid files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



429
# File 'lib/gmt.rb', line 429

wrapper_other :grdgradient

#grdhisteq(*arguments, options) ⇒ Boolean

Histogram equalization for grid files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



432
# File 'lib/gmt.rb', line 432

wrapper_other :grdhisteq

#grdimage(*files, options) ⇒ Boolean

Produce images from 2-D gridded data sets

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



222
# File 'lib/gmt.rb', line 222

wrapper_ps :grdimage

#grdinfo(*arguments, options) ⇒ Boolean

Get information about grid files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



333
# File 'lib/gmt.rb', line 333

wrapper_other :grdinfo

#grdlandmask(*arguments, options) ⇒ Boolean

Create masking grid files from shoreline data base

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



435
# File 'lib/gmt.rb', line 435

wrapper_other :grdlandmask

#grdmask(*arguments, options) ⇒ Boolean

Reset grid nodes in/outside a clip path to constants

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



438
# File 'lib/gmt.rb', line 438

wrapper_other :grdmask

#grdmath(*arguments, options) ⇒ Boolean

Mathematical operations on grid files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



441
# File 'lib/gmt.rb', line 441

wrapper_other :grdmath

#grdpaste(*arguments, options) ⇒ Boolean

Paste together grid files along a common edge

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



390
# File 'lib/gmt.rb', line 390

wrapper_other :grdpaste

#grdproject(*arguments, options) ⇒ Boolean

Project gridded data sets onto a new coordinate system

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



309
# File 'lib/gmt.rb', line 309

wrapper_other :grdproject

#grdsample(*arguments, options) ⇒ Boolean

Resample a 2-D gridded data set onto a new grid

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



297
# File 'lib/gmt.rb', line 297

wrapper_other :grdsample

#grdtrack(*arguments, options) ⇒ Boolean

Sampling of 2-D gridded data set(s) along 1-D track

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



300
# File 'lib/gmt.rb', line 300

wrapper_other :grdtrack

#grdvector(*files, options) ⇒ Boolean

Plotting of 2-D gridded vector fields

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



225
# File 'lib/gmt.rb', line 225

wrapper_ps :grdvector

#grdview(*files, options) ⇒ Boolean

3-D perspective imaging of 2-D gridded data sets

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



228
# File 'lib/gmt.rb', line 228

wrapper_ps :grdview

#grdvolume(*arguments, options) ⇒ Boolean

Calculate volumes under a surface within specified contour

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



444
# File 'lib/gmt.rb', line 444

wrapper_other :grdvolume

#greenspline(*arguments, options) ⇒ Boolean

Interpolation with Green’s functions for splines in 1–3 D

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



276
# File 'lib/gmt.rb', line 276

wrapper_other :greenspline

#kml2gmt(*arguments, options) ⇒ Boolean

Extracts coordinates from Google Earth KML files

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



453
# File 'lib/gmt.rb', line 453

wrapper_other :kml2gmt

#makecpt(*arguments, options) ⇒ Boolean

Make color palette tables

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



342
# File 'lib/gmt.rb', line 342

wrapper_other :makecpt

#mapproject(*arguments, options) ⇒ Boolean

Transformation of coordinate systems for table data

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



312
# File 'lib/gmt.rb', line 312

wrapper_other :mapproject

#nearneighbor(*arguments, options) ⇒ Boolean

Nearest-neighbor gridding scheme

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



279
# File 'lib/gmt.rb', line 279

wrapper_other :nearneighbor

#project(*arguments, options) ⇒ Boolean

Project table data onto lines or great circles

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



315
# File 'lib/gmt.rb', line 315

wrapper_other :project

#psbasemap(*files, options) ⇒ Boolean

Create a basemap plot

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



231
# File 'lib/gmt.rb', line 231

wrapper_ps :psbasemap

#psclip(*files, options) ⇒ Boolean

Use polygon files to define clipping paths

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



234
# File 'lib/gmt.rb', line 234

wrapper_ps :psclip

#pscoast(*files, options) ⇒ Boolean

Plot (and fill) coastlines, borders, and rivers on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



237
# File 'lib/gmt.rb', line 237

wrapper_ps :pscoast

#pscontour(*files, options) ⇒ Boolean

Contour or image raw table data by triangulation

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



240
# File 'lib/gmt.rb', line 240

wrapper_ps :pscontour

#psconvert(*arguments, options) ⇒ Boolean

Crop and convert PostScript files to raster images, EPS, and PDF

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



456
# File 'lib/gmt.rb', line 456

wrapper_other :psconvert

#pshistogram(*files, options) ⇒ Boolean

Plot a histogram

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



243
# File 'lib/gmt.rb', line 243

wrapper_ps :pshistogram

#psimage(*files, options) ⇒ Boolean

Plot Sun raster files on a map

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



246
# File 'lib/gmt.rb', line 246

wrapper_ps :psimage

#pslegend(*files, options) ⇒ Boolean

Plot a legend on a map

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



249
# File 'lib/gmt.rb', line 249

wrapper_ps :pslegend

#psmask(*files, options) ⇒ Boolean

Create overlay to mask out regions on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



252
# File 'lib/gmt.rb', line 252

wrapper_ps :psmask

#psrose(*files, options) ⇒ Boolean

Plot sector or rose diagrams

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



255
# File 'lib/gmt.rb', line 255

wrapper_ps :psrose

#psscale(*files, options) ⇒ Boolean

Plot gray scale or color scale on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



258
# File 'lib/gmt.rb', line 258

wrapper_ps :psscale

#pstext(*files, options) ⇒ Boolean

Plot text strings on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



261
# File 'lib/gmt.rb', line 261

wrapper_ps :pstext

#pswiggle(*files, options) ⇒ Boolean

Draw table data time-series along track on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



264
# File 'lib/gmt.rb', line 264

wrapper_ps :pswiggle

#psxy(*files, options) ⇒ Boolean

Plot symbols, polygons, and lines on maps

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



267
# File 'lib/gmt.rb', line 267

wrapper_ps :psxy

#psxyz(*files, options) ⇒ Boolean

Plot symbols, polygons, and lines in 3-D

A PostScript function (accepts :file and :position options).

Parameters:

  • files (Array<String>)

    The input files

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



270
# File 'lib/gmt.rb', line 270

wrapper_ps :psxyz

#sample1d(*arguments, options) ⇒ Boolean

Resampling of 1-D table data sets

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



303
# File 'lib/gmt.rb', line 303

wrapper_other :sample1d

#spectrum1d(*arguments, options) ⇒ Boolean

Compute various spectral estimates from time-series

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



345
# File 'lib/gmt.rb', line 345

wrapper_other :spectrum1d

#sph2grd(*arguments, options) ⇒ Boolean

Compute grid from spherical harmonic coefficients

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



348
# File 'lib/gmt.rb', line 348

wrapper_other :sph2grd

#sphdistance(*arguments, options) ⇒ Boolean

Make grid of distances to nearest points on a sphere

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



351
# File 'lib/gmt.rb', line 351

wrapper_other :sphdistance

#sphinterpolate(*arguments, options) ⇒ Boolean

Spherical gridding in tension of data on a sphere

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



282
# File 'lib/gmt.rb', line 282

wrapper_other :sphinterpolate

#sphtriangulate(*arguments, options) ⇒ Boolean

Delaunay or Voronoi construction of spherical lon,lat data

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



354
# File 'lib/gmt.rb', line 354

wrapper_other :sphtriangulate

#splitxyz(*arguments, options) ⇒ Boolean

Split xyz files into several segments

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



393
# File 'lib/gmt.rb', line 393

wrapper_other :splitxyz

#surface(*arguments, options) ⇒ Boolean

A continuous curvature gridding algorithm

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



285
# File 'lib/gmt.rb', line 285

wrapper_other :surface

#trend1d(*arguments, options) ⇒ Boolean

Fits polynomial or Fourier trends to y = f(x) series

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



408
# File 'lib/gmt.rb', line 408

wrapper_other :trend1d

#trend2d(*arguments, options) ⇒ Boolean

Fits polynomial trends to z = f(x,y) series

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



411
# File 'lib/gmt.rb', line 411

wrapper_other :trend2d

#triangulate(*arguments, options) ⇒ Boolean

Perform optimal Delauney triangulation and gridding

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



288
# File 'lib/gmt.rb', line 288

wrapper_other :triangulate

#xyz2grd(*arguments, options) ⇒ Boolean

Convert an equidistant table xyz file to a 2-D grid file

Parameters:

  • arguments (Array<String>)

    The arguments

  • options (Hash)

    The GMT command-line options in hash form

Returns:

  • (Boolean)

    true on success

See Also:



396
# File 'lib/gmt.rb', line 396

wrapper_other :xyz2grd